@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2015-08-19'; # DATE
-our $VERSION = '0.69'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.70'; # VERSION
 
 use 5.010001;
 use strict;
@@ -181,6 +181,8 @@ sub _args2opts {
         my $is_simple_scalar = $type =~ $re_simple_scalar;
         my $is_array_of_simple_scalar = $type eq 'array' &&
             $cs->{of} && $cs->{of}[0] =~ $re_simple_scalar;
+        my $can_be_comma_separated = $is_array_of_simple_scalar &&
+            $cs->{of}[0] =~ /\A(int|float)\z/; # XXX as well as str that cannot contain commas
 
         my $stash = {};
 
@@ -212,8 +214,14 @@ sub _args2opts {
 
             if ($is_array_of_simple_scalar) {
                 $rargs->{$arg} //= [];
-                $val_set = 1; $val = $_[1];
-                push @{ $rargs->{$arg} }, $val;
+                $val_set = 1;
+                if ($can_be_comma_separated) {
+                    $val = [split /\s*,\s*/, $_[1]];
+                    push @{ $rargs->{$arg} }, @$val;
+                } else {
+                    $val = $_[1];
+                    push @{ $rargs->{$arg} }, $val;
+                }
             } elsif ($is_simple_scalar) {
                 $val_set = 1; $val = $_[1];
                 $rargs->{$arg} = $val;
@@ -1000,7 +1008,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.69 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-08-19.
+This document describes version 0.70 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
@@ -1020,9 +1028,8 @@ processed, see Perinci::CmdLine's documentation.
 
 =head2 gen_getopt_long_spec_from_meta(%args) -> [status, msg, result, meta]
 
-{en_US Generate Getopt::Long spec from Rinci function metadata}.
+Generate Getopt::Long spec from Rinci function metadata.
 
-{en_US 
 This routine will produce a C<Getopt::Long> specification from Rinci function
 metadata, as well as some more data structure in the result metadata to help
 producing a command-line help/usage message.
@@ -1067,7 +1074,8 @@ Will produce a hash (Getopt::Long spec), with C<func.specmeta>, C<func.opts>,
 C<func.common_opts>, C<func.func_opts> that contain extra information
 (C<func.specmeta> is a hash of getopt spec name and a hash of extra information
 while C<func.*opts> lists all used option names).
-}
+
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -1075,13 +1083,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<args> => I<hash>
 
-{en_US Reference to hash which will store the result}.
+Reference to hash which will store the result.
 
 =item * B<common_opts> => I<hash>
 
-{en_US Common options}.
+Common options.
 
-{en_US 
 A hash where the values are hashes containing these keys: C<getopt> (Getopt::Long
 option specification), C<handler> (Getopt::Long handler). Will be passed to
 C<get_args_from_argv()>. Example:
@@ -1099,44 +1106,36 @@ C<get_args_from_argv()>. Example:
      },
  }
 
-}
-
 =item * B<ignore_converted_code> => I<bool> (default: 0)
 
-{en_US Whether to ignore coderefs converted to string}.
+Whether to ignore coderefs converted to string.
 
-{en_US 
 Across network through JSON encoding, coderef in metadata (e.g. in
 C<cmdline_aliases> property) usually gets converted to string C<CODE>. In some
 cases, like for tab completion, this is pretty harmless so you can turn this
 option on. For example, in the case of C<cmdline_aliases>, the effect is just
 that command-line aliases code are not getting executed, but this is usually
 okay.
-}
 
 =item * B<meta>* => I<hash>
 
-{en_US Rinci function metadata}.
+Rinci function metadata.
 
 =item * B<meta_is_normalized> => I<bool>
 
 =item * B<per_arg_json> => I<bool> (default: 0)
 
-{en_US Whether to add --NAME-json for non-simple arguments}.
+Whether to add --NAME-json for non-simple arguments.
 
-{en_US 
 Will also interpret command-line arguments as JSON if assigned to function
 arguments, if arguments' schema is not simple scalar.
-}
 
 =item * B<per_arg_yaml> => I<bool> (default: 0)
 
-{en_US Whether to add --NAME-yaml for non-simple arguments}.
+Whether to add --NAME-yaml for non-simple arguments.
 
-{en_US 
 Will also interpret command-line arguments as YAML if assigned to function
 arguments, if arguments' schema is not simple scalar.
-}
 
 =back
 
@@ -1154,9 +1153,8 @@ Return value:  (any)
 
 =head2 get_args_from_argv(%args) -> [status, msg, result, meta]
 
-{en_US Get subroutine arguments (%args) from command-line arguments (@ARGV)}.
+Get subroutine arguments (%args) from command-line arguments (@ARGV).
 
-{en_US 
 Using information in Rinci function metadata's C<args> property, parse command
 line arguments C<@argv> into hash C<%args>, suitable for passing into subroutines.
 
@@ -1168,7 +1166,8 @@ preserve the original.
 
 See also: gen_getopt_long_spec_from_meta() which is the routine that generates
 the specification.
-}
+
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -1176,28 +1175,25 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_extra_elems> => I<bool> (default: 0)
 
-{en_US Allow extra/unassigned elements in argv}.
+Allow extra/unassigned elements in argv.
 
-{en_US 
 If set to 1, then if there are array elements unassigned to one of the
 arguments, instead of generating an error, this function will just ignore them.
 
 This option will be passed to Perinci::Sub::GetArgs::Array's allow_extra_elems.
-}
 
 =item * B<args> => I<hash>
 
-{en_US Specify input args, with some arguments preset}.
+Specify input args, with some arguments preset.
 
 =item * B<argv> => I<array[str]>
 
-{en_US If not specified, defaults to @ARGV}
+If not specified, defaults to @ARGV
 
 =item * B<common_opts> => I<hash>
 
-{en_US Common options}.
+Common options.
 
-{en_US 
 A hash where the values are hashes containing these keys: C<getopt> (Getopt::Long
 option specification), C<handler> (Getopt::Long handler). Will be passed to
 C<get_args_from_argv()>. Example:
@@ -1215,29 +1211,24 @@ C<get_args_from_argv()>. Example:
      },
  }
 
-}
-
 =item * B<ignore_converted_code> => I<bool> (default: 0)
 
-{en_US Whether to ignore coderefs converted to string}.
+Whether to ignore coderefs converted to string.
 
-{en_US 
 Across network through JSON encoding, coderef in metadata (e.g. in
 C<cmdline_aliases> property) usually gets converted to string C<CODE>. In some
 cases, like for tab completion, this is harmless so you can turn this option on.
-}
 
 =item * B<meta>* => I<hash>
 
 =item * B<meta_is_normalized> => I<bool> (default: 0)
 
-{en_US Can be set to 1 if your metadata is normalized, to avoid duplicate effort}.
+Can be set to 1 if your metadata is normalized, to avoid duplicate effort.
 
 =item * B<on_missing_required_args> => I<code>
 
-{en_US Execute code when there is missing required args}.
+Execute code when there is missing required args.
 
-{en_US 
 This can be used to give a chance to supply argument value from other sources if
 not specified by command-line options. Perinci::CmdLine, for example, uses this
 hook to supply value from STDIN or file contents (if argument has C<cmdline_src>
@@ -1249,13 +1240,11 @@ $the_resulting_args_so_far, spec => $the_arg_spec).
 
 The hook can return true if it succeeds in making the missing situation
 resolved. In this case, this function will not report the argument as missing.
-}
 
 =item * B<per_arg_json> => I<bool> (default: 0)
 
-{en_US Whether to recognize --ARGNAME-json}.
+Whether to recognize --ARGNAME-json.
 
-{en_US 
 This is useful for example if you want to specify a value which is not
 expressible from the command-line, like 'undef'.
 
@@ -1266,26 +1255,22 @@ But every other string will need to be quoted:
  % script.pl --name-json '"foo"'
 
 See also: per_arg_yaml. You should enable just one instead of turning on both.
-}
 
 =item * B<per_arg_yaml> => I<bool> (default: 0)
 
-{en_US Whether to recognize --ARGNAME-yaml}.
+Whether to recognize --ARGNAME-yaml.
 
-{en_US 
 This is useful for example if you want to specify a value which is not
 expressible from the command-line, like 'undef'.
 
  % script.pl --name-yaml '~'
 
 See also: per_arg_json. You should enable just one instead of turning on both.
-}
 
 =item * B<strict> => I<bool> (default: 1)
 
-{en_US Strict mode}.
+Strict mode.
 
-{en_US 
 If set to 0, will still return parsed argv even if there are parsing errors
 (reported by Getopt::Long). If set to 1 (the default), will die upon error.
 
@@ -1294,7 +1279,6 @@ strict is used by, for example, Perinci::Sub::Complete during completion where
 the command-line might still be incomplete.
 
 Should probably be named C<ignore_errors>. :-)
-}
 
 =back
 
@@ -1310,7 +1294,6 @@ that contains extra information.
 Return value:  (any)
 
 
-{en_US 
 Error codes:
 
 =over
@@ -1322,7 +1305,6 @@ specification (only if 'strict' mode is enabled).
 
 =item * 501 - coderef in cmdline_aliases got converted into a string, probably because
 the metadata was transported (e.g. through Riap::HTTP/Riap::Simple).
-}
 
 =back
 
